@@ -24,20 +24,20 @@ def read_abi(path):
 w3 = Web3(Web3.HTTPProvider('https://rpc.ankr.com/avalanche_fuji'))
 
 # Default version
-DEFAULT_VERSION = "v4"
+DEFAULT_VERSION = "v5"
 
 # Load contract JSONs
 ERC20ABI = json.loads(read_abi('abis/IERC20Metadata.json'))
-IArrowRouterABI = json.loads(read_abi('abis/v4/IArrowRouter.json'))
-IArrowEventsABI = json.loads(read_abi('abis/v4/IArrowEvents.json'))
-IArrowRegistryABI = json.loads(read_abi('abis/v4/IArrowRegistry.json'))
-ArrowOptionChainProxyV4ABI = json.loads(read_abi('abis/competition/ArrowOptionChainProxy.json'))
-ArrowOptionChainProxyCompetitionABI = json.loads(read_abi('abis/v4/ArrowOptionChainProxy.json'))
+IArrowRouterABI = json.loads(read_abi('abis/v5/IArrowRouter.json'))
+IArrowEventsABI = json.loads(read_abi('abis/v5/IArrowEvents.json'))
+IArrowRegistryABI = json.loads(read_abi('abis/v5/IArrowRegistry.json'))
+ArrowOptionChainProxyv5ABI = json.loads(read_abi('abis/competition/ArrowOptionChainProxy.json'))
+ArrowOptionChainProxyCompetitionABI = json.loads(read_abi('abis/v5/ArrowOptionChainProxy.json'))
 
 # Bytecode
 bytecodeHashes = {
     "ArrowOptionChainProxy": {
-        "v4": Web3.solidityKeccak(["bytes"], [ArrowOptionChainProxyV4ABI["bytecode"]]),
+        "v5": Web3.solidityKeccak(["bytes"], [ArrowOptionChainProxyv5ABI["bytecode"]]),
         "competition": Web3.solidityKeccak(["bytes"], [ArrowOptionChainProxyCompetitionABI["bytecode"]])
     }
 }
@@ -45,7 +45,7 @@ bytecodeHashes = {
 addresses = {
     "fuji": {
         "router": {
-            "v4": "0x752Fe3cC44F785EB1e4A8a6237adAe24184d9979",
+            "v5": "0xaB12c83893ba35f2e4CEeA65429c5805CC86D4bD",
             "competition": "0xD05D064DBDCf8dB7D87EcD7E06c63874Bb968AA6"
         }
     }
@@ -53,7 +53,7 @@ addresses = {
 
 urls = {
     "api": {
-        "v4": "https://fuji-v5-api.arrow.markets/v1",
+        "v5": "https://fuji-v5-api.arrow.markets/v1",
         "competition": "https://competition-v5-api.arrow.markets/v1"
     },
     "provider": {
@@ -73,7 +73,7 @@ coingeckoIDs = {
     "BTC": "bitcoin"
 }
 
-versions = {"v4", "competition"}
+versions = {"v5", "competition"}
 secondsPerDay = 60 * 60 * 24
 quantityScaleFactor = 10**2
 
@@ -123,7 +123,7 @@ class DeliverOptionParams(OptionOrderParams):
 # **********************************
 
 class Version:
-    V4 = "v4"
+    v5 = "v5"
     COMPETITION = "competition"
 
 class ContractType:
@@ -149,7 +149,7 @@ def isValidVersion(version):
 """"
  * Get the router contract from Arrow's contract suite.
  *
- * @param version Version of Arrow contract suite with which to interact. Default is V4.
+ * @param version Version of Arrow contract suite with which to interact. Default is v5.
  * @param wallet Wallet with which you want to connect the instance of the router contract. Default is Fuji provider.
  * @returns Local instance of ethers.Contract for the Arrow router contract.
 """
@@ -166,7 +166,7 @@ def getRouterContract(version=DEFAULT_VERSION):
 """"
  * Get the stablecoin contract that is associated with Arrow's contract suite.
  *
- * @param version Version of Arrow contract suite with which to interact. Default is V4.
+ * @param version Version of Arrow contract suite with which to interact. Default is v5.
  * @param wallet Wallet with which you want to connect the instance of the stablecoin contract. Default is Fuji provider.
  * @returns Local instance of ethers.Contract for the stablecoin contract.
 """
@@ -183,7 +183,7 @@ def getStablecoinContract(version=DEFAULT_VERSION):
 """"
  * Get the events contract from Arrow's contract suite.
  *
- * @param version Version of Arrow contract suite with which to interact. Default is V4.
+ * @param version Version of Arrow contract suite with which to interact. Default is v5.
  * @param wallet Wallet with which you want to connect the instance of the Arrow events contract. Default is Fuji provider.
  * @returns Local instance of ethers.Contract for the Arrow events contract.
 """
@@ -200,7 +200,7 @@ def getEventsContract(version=DEFAULT_VERSION):
 """"
  * Get the registry contract from Arrow's registry suite.
  *
- * @param version Version of Arrow contract suite with which to interact. Default is V4.
+ * @param version Version of Arrow contract suite with which to interact. Default is v5.
  * @param wallet Wallet with which you want to connect the instance of the Arrow registry contract. Default is Fuji provider.
  * @returns Local instance of ethers.Contract for the Arrow registry contract.
 """
@@ -367,7 +367,7 @@ def isFriday(unixTimestamp):
  *
  * @param ticker Ticker of the underlying asset.
  * @param readableExpiration Readable expiration in the "MMDDYYYY" format.
- * @param version Version of Arrow contract suite with which to interact. Default is V4.
+ * @param version Version of Arrow contract suite with which to interact. Default is v5.
  * @param wallet Wallet with which you want to connect the instance of the Arrow registry contract. Default is Fuji provider.
  * @returns Address of the option chain corresponding to the passed ticker and expiration.
 """
@@ -375,7 +375,7 @@ def computeOptionChainAddress(ticker, readableExpiration, version=DEFAULT_VERSIO
     # Get chain factory contract address from router
     router = getRouterContract(version)
 
-    if version == "v4" or version == "competition":
+    if version == "v5" or version == "competition":
         optionChainFactoryAddress = router.functions.getOptionChainFactoryAddress().call()
     else:
         raise UNSUPPORTED_VERSION_ERROR
@@ -398,7 +398,7 @@ def computeOptionChainAddress(ticker, readableExpiration, version=DEFAULT_VERSIO
  * Compute address of on-chain short aggregator contract using CREATE2 functionality.
  *
  * @param ticker Ticker of the underlying asset.
- * @param version Version of Arrow contract suite with which to interact. Default is V4.
+ * @param version Version of Arrow contract suite with which to interact. Default is v5.
  * @param wallet Wallet with which you want to connect the instance of the Arrow registry contract. Default is Fuji provider.
  * @returns Address of the short aggregator corresponding to the passed ticker.
 """
@@ -406,7 +406,7 @@ def computeShortAggregatorAddress(ticker, version=DEFAULT_VERSION):
     # Get local instance of router contract
     router = getRouterContract(version)
 
-    if version == "v4" or version == "competition":
+    if version == "v5" or version == "competition":
         shortAggregatorFactoryAddress = router.functions.getShortAggregatorFactoryAddress().call()
     else:
         raise UNSUPPORTED_VERSION_ERROR
@@ -429,7 +429,7 @@ def computeShortAggregatorAddress(ticker, version=DEFAULT_VERSION):
  * Help construct DeliverOptionParams object that can be passed to the Arrow API to submit an option order.
  *
  * @param optionOrderParams Object containing parameters necesssary in computing parameters for submitting an option order.
- * @param version Version of Arrow contract suite with which to interact. Default is V4.
+ * @param version Version of Arrow contract suite with which to interact. Default is v5.
  * @param wallet Wallet with which you want to submit the option order.
  * @returns JSON that contains the variables necessary in completing the option order.
 """
@@ -452,7 +452,7 @@ def prepareDeliverOptionParams(optionOrderParams: List[OptionOrderParams], versi
     bigNumberStrike = [round(strike) for strike in bigNumberStrike]
     formattedStrike = "|".join(strikes)
 
-    if version == "v4" or version == "competition":
+    if version == "v5" or version == "competition":
         intQuantity = round(optionOrderParams["quantity"] * quantityScaleFactor)
     else: 
         raise UNSUPPORTED_VERSION_ERROR
@@ -535,4 +535,19 @@ def getGeoLocation():
             "country": None,
             "error": True
         }
+
+"""
+ * Given a contract type and order type, determines the readable contract type.
+ *
+ * @returns The readable contract type.
+"""
+def getReadableContractType(contractType, orderType):
+    if contractType ==  ContractType.CALL_SPREAD or contractType == ContractType.PUT_SPREAD:
+        if orderType in [OrderType.LONG_OPEN, OrderType.LONG_CLOSE]:
+            return "Call Debit Spread" if contractType == ContractType.CALL_SPREAD else "Put Debit Spread"
+        return "Call Credit Spread" if contractType == ContractType.CALL_SPREAD else "Put Credit Spread"
+    elif contractType == ContractType.CALL or contractType == ContractType.PUT:
+        if orderType in [OrderType.LONG_OPEN, OrderType.LONG_CLOSE]:
+            return "Long Call" if contractType == ContractType.CALL else "Long Put"
+        return "Short Call" if contractType == ContractType.CALL else "Short Put"
     
\ No newline at end of file
